@@ -173,7 +173,8 @@ void
 writeheader(FILE *fp)
 {
 	if (description[0]) {
-		putchar('t');
+		if (description[0] == '[')
+			fputs("[|", fp);
 		gphtext(fp, description, strlen(description));
 		fputs("\n\n", fp);
 	}
@@ -253,6 +254,8 @@ main(int argc, char *argv[])
 	git_libgit2_init();
 	for (i = 1; i <= GIT_CONFIG_LEVEL_APP; i++)
 		git_libgit2_opts(GIT_OPT_SET_SEARCH_PATH, i, "");
+	/* do not require the git repository to be owned by the current user */
+	git_libgit2_opts(GIT_OPT_SET_OWNER_VALIDATION, 0);
 
 #ifdef __OpenBSD__
 	if (pledge("stdio rpath", NULL) == -1)
