@@ -463,9 +463,9 @@ gphtextnl(FILE *fp, const char *s, size_t len)
 	size_t i, n = 0;
 
 	for (i = 0; s[i] && i < len; i++) {
-		/* escape with 't' at the start of a line */
-		if (!n && (s[i] == 't' || s[i] == '['))
-			putc('t', fp);
+		/* escape '[' with "[|" at the start of a line */
+		if (!n && s[i] == '[')
+			fputs("[|", fp);
 
 		switch (s[i]) {
 		case '\t': fputs("        ", fp);
@@ -592,7 +592,8 @@ printtimeshort(FILE *fp, const git_time *intime)
 void
 writeheader(FILE *fp, const char *title)
 {
-	putc('t', fp);
+	if (title[0] == '[')
+		fputs("[|", fp);
 	gphtext(fp, title, strlen(title));
 	if (title[0] && strippedname[0])
 		fputs(" - ", fp);
@@ -795,7 +796,8 @@ printshowfile(FILE *fp, struct commitinfo *ci)
 			if (git_patch_get_hunk(&hunk, &nhunklines, patch, j))
 				break;
 
-			putc('t', fp);
+			if (hunk->header_len > 0 && hunk->header[0] == '[')
+				fputs("[|", fp);
 			gphtext(fp, hunk->header, hunk->header_len);
 			putc('\n', fp);
 
@@ -1024,7 +1026,8 @@ writeblob(git_object *obj, const char *fpath, const char *filename, size_t files
 
 	fp = efopen(fpath, "w");
 	writeheader(fp, filename);
-	putc('t', fp);
+	if (filename[0] == '[')
+		fputs("[|", fp);
 	gphtext(fp, filename, strlen(filename));
 	fprintf(fp, " (%zuB)\n", filesize);
 	fputs("---\n", fp);
@@ -1296,6 +1299,8 @@ main(int argc, char *argv[])
 	git_libgit2_init();
 	for (i = 1; i <= GIT_CONFIG_LEVEL_APP; i++)
 		git_libgit2_opts(GIT_OPT_SET_SEARCH_PATH, i, "");
+	/* do not require the git repository to be owned by the current user */
+	git_libgit2_opts(GIT_OPT_SET_OWNER_VALIDATION, 0);
 
 #ifdef __OpenBSD__
 	if (unveil(repodir, "r") == -1)
